function [] = formatplot(HH, h, TT, TT2)
%function [] = formatplot(HH, h, TT, TT2)
% This function is basically used for formatting Figures (because the MATLAB
% default formatting often is not suitable for publication)
%
% INPUTS:
%       HH:	Figure handle ('gcf' usually)
%	h:	Usually 'gca' --axis handle
%       TT:     Handles to titles and legends
%       TT2:    Handles to titles and legends with larger font and more bolded
%
% NOTE: Feel free to change this little function for a specific plotting 
% application, but the put a local copy of this file in the example folder. 
%
% Author: Matt Ueckermann

for i = 1:length(HH)
    set(HH(i),'LineWidth',2,'MarkerSize',2)
end
set(h,'fontsize',12)
for i = 1:length(TT)
    set(TT(i),'fontsize',12)
end

if nargin==4
    for i = 1:length(TT2)
        set(TT2(i),'fontsize',13,'FontWeight','bold')
    end
end
